@@ -5,7 +5,7 @@
 import inspect
 import json
 from importlib import import_module
-from typing import Any, Callable, Dict, Sequence, Tuple, Union
+from typing import Any, Callable, Sequence, Union
 
 from pydantic import BaseModel
 
@@ -15,7 +15,7 @@ class SplitFuncDataClass(BaseModel):
 
     function: Union[str, Callable]
     arguments: Union[
-        str, Dict[str, Any]
+        str, dict[str, Any]
     ]  # JSON string holding the function parameters or dict
 
     def __getitem__(self, key: str):
@@ -64,13 +64,13 @@ class SplitFuncDataClass(BaseModel):
 
         return split_func
 
-    def _load_arguments(self) -> Dict[str, Any]:
+    def _load_arguments(self) -> dict[str, Any]:
         """Load the arguments.
 
         Convert the arguments from JSON if they are given as strings or simply return them otherwise.
 
         Returns:
-            arguments (Dict[str, Any]): The additional arguments to be passed to he function
+            arguments (dict[str, Any]): The additional arguments to be passed to he function
 
         """
         if isinstance(self.arguments, str):
@@ -80,18 +80,18 @@ class SplitFuncDataClass(BaseModel):
 
     def load(
         self, required_arguments: Sequence[str] = None
-    ) -> Tuple[Callable, Dict[str, Any]]:
+    ) -> tuple[Callable, dict[str, Any]]:
         """Load the function and its arguments.
 
         If the function and the arguments are given as strings in the instane attributes, load them as Python objects
         otherwise just return them from the instance attributes.
 
         Args:
-            required_arguments (List[str]): list of arguments the loaded function must have
+            required_arguments (list[str]): list of arguments the loaded function must have
 
         Returns:
             - function (Callable)
-            - arguments (Dict[str, Any])
+            - arguments (dict[str, Any])
 
         """
         return self._load_split_function(required_arguments), self._load_arguments()
